@@ -94,9 +94,6 @@ void PartitionManagerWidget::init(OperationStack* ostack)
 {
     m_OperationStack = ostack;
 
-    // TODO: shouldn't this also go to the main window class?
-    FileSystemFactory::init();
-
     loadConfig();
     setupConnections();
 }
@@ -244,7 +241,7 @@ void PartitionManagerWidget::updatePartitions()
 
     QFont font;
     font.setBold(true);
-    font.setWeight(75);
+    font.setWeight(QFont::Bold);
     deviceItem->setFont(0, font);
 
     deviceItem->setText(0, selectedDevice()->prettyName());
@@ -285,6 +282,25 @@ void PartitionManagerWidget::on_m_TreePartitions_currentItemChanged(QTreeWidgetI
         partTableWidget().setActiveWidget(nullptr);
 }
 
+bool PartitionManagerWidget::setCurrentPartitionByName(const QString& name)
+{
+    auto rootNode = treePartitions().invisibleRootItem();
+    for (int i = 0; i < rootNode->childCount(); i++) {
+        auto driveNode = rootNode->child(i);
+        for (int e = 0; e < driveNode->childCount(); e++) {
+            auto partitionNode = driveNode->child(e);
+            const QString text = partitionNode->data(0, Qt::DisplayRole).toString();
+            if (text.endsWith(name)) {
+                partitionNode->setSelected(true);
+                treePartitions().setCurrentItem(partitionNode);
+                return true;
+            }
+        }
+    }
+
+    return false;
+}
+
 void PartitionManagerWidget::on_m_TreePartitions_itemDoubleClicked(QTreeWidgetItem* item, int)
 {
     if (item == treePartitions().topLevelItem(0)) {
@@ -507,10 +523,14 @@ void PartitionManagerWidget::onNewPartition()
     Partition* newPartition = NewOperation::createNew(*selectedPartition(), static_cast<FileSystem::Type>(Config::defaultFileSystem()));
 
     QPointer<NewDialog> dlg = new NewDialog(this, *selectedDevice(), *newPartition, selectedDevice()->partitionTable()->childRoles(*selectedPartition()));
-    if (dlg->exec() == QDialog::Accepted)
+    if (dlg->exec() == QDialog::Accepted) {
+        if (dlg->useUnsecuredPartition()) {
+            newPartition->fileSystem().setPosixPermissions(QStringLiteral("777"));
+        }
         operationStack().push(new NewOperation(*selectedDevice(), newPartition));
-    else
+    } else {
         delete newPartition;
+    }
 
     delete dlg;
 }
